/*
 * SolutionCheck.java
 *
 * Created on 13 mai 2002
 */
 
/** Class SolutionCheck <p>
 * This is the main class of the solution checking program. 
 * This Class reads the instance file and creates the objects associated with this
 * instance : an InstanceProblem object and the associated Request, Strip, Image and
 * GeoPoint objects. Right after, it reads the constants file.
 * Then it reads the solution file and creates the list of Image objects associated with 
 * this solution.
 * Then it tests whether this solution is feasible. If so, it computes its gain. 
 * If not, it informs the user that it is not feasible.<br>
 * Company:      ONERA/DCSD/CD
 * @author Matthieu Lombard mlombard@operamail.com
 * @version 0.0
 * @see InstanceProblem
 * @see Constants
 * @see Solution
 */


import java.io.*;
import java.util.*;

public class SolutionCheck {

//-----------------------------------------------------------------------------------
//*******************            A T T R I B U T E S            *********************
//-----------------------------------------------------------------------------------
  
  /** names of the files containing the information related to the instance, the solution,
   * the constants and the result   */  
  private static String instanceFileName;
  private static String solutionFileName;
  private static String constantsFileName;
  private static String resultFileName;

//-----------------------------------------------------------------------------------
//*******************         C O N S T R U C T O R S            ********************
//----------------------------------------------------------------------------------- 

  public SolutionCheck () {

    System.out.println("\nChecking file existency ...");
    
    //checking the existence of the files      
    if ( !checkFileExistence(instanceFileName) ) 
         System.exit(1);
    if ( !checkFileExistence(solutionFileName) ) 
         System.exit(1);
    if ( !checkFileExistence(constantsFileName) ) 
         System.exit(1); 

    System.out.println("All files exist!");
    
    //initializing the problem
    InstanceProblem instanceProblem = new InstanceProblem(instanceFileName);
    System.out.println(instanceProblem.toString());

    //reading the constants 
    Constants constants = new Constants(constantsFileName);
    System.out.println(constants.toString());
    
    //verifying the solution
    Solution solution = new Solution(solutionFileName, resultFileName);
    
  }

//-----------------------------------------------------------------------------------
//**********************************  M A I N   *************************************
//-----------------------------------------------------------------------------------   
  /** Main method. The arguments of this method are:<br>
   *     1 - the complete name (including the path) of the file containing the instance<br>
   *     2 - the complete name (including the path) of the file containing the solution<br>
   *     3 - the complete name (including the path) of the file containing the constants<br>
   *     4 - the complete name (including the path) of the file containing the result <br>
   */
   
  public static void main(String[] args) {
    
    System.out.println("\n----------------------------------------------------------------------");
    System.out.println("--        Challenge ROADEF 2003 -  Solution  Checking Program       --");
    System.out.println("----------------------------------------------------------------------");
    
    //getting the file names
    instanceFileName  =  args[0];
    solutionFileName  =  args[1];
    constantsFileName =  args[2];
    resultFileName    =  args[3];
    
    SolutionCheck solCheck = new SolutionCheck();
       
  }//main

//-----------------------------------------------------------------------------------
//*******************              M E T H O D S                 ********************
//----------------------------------------------------------------------------------- 
  //------------------------checkFilesDirectories--------------------------------------
  /** Method that checks whether the specified file exists or not
   * @param fileName the name of the file
   * @return a boolean signaling that the file exists
   */
  public static boolean checkFileExistence ( String fileName ) {
    
    //checking the existence of the file
    File checkedFile = new File(fileName);
    
    if ( checkedFile.exists() ) {
         return true;
    }
    else {
         System.out.println("*** Error : file " + fileName + " does not exist. Exiting program...");
         return false;
    }      
    
  }//checkFilesDirectories

}//SolutionCheck.java

